@@ -1,5 +1,6 @@
 use super::get_path::concatenate_or_return_absolute;
-use std::{fs, io, path::Path};
+use std::path::Path;
+use std::{fs, io};
 
 /// *Unsandboxed* function similar to `remove_file`, but which does not perform
 /// sandboxing.
